.. S1Tiling documentation master file, created by
   sphinx-quickstart on Mon Sep 14 12:38:14 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. role:: raw-html(raw)
    :format: html

S1Tiling |release| -- documentation
====================================

:raw-html:`<script type='text/javascript' src='https://www.openhub.net/p/S1Tiling/widgets/project_users_logo?format=js'></script>`
:raw-html:`<br>`
|Badge Fury|
|Badge doc|
|Badge discourse|
:raw-html:`<br>`
|License|
|Python Versions|

.. |Badge Fury| image:: https://badge.fury.io/py/S1Tiling.svg
   :target: https://badge.fury.io/py/S1Tiling

.. |Badge discourse| image:: https://img.shields.io/discourse/status?server=https%3A%2F%2Fforum.orfeo-toolbox.org%2F
   :target: https://forum.orfeo-toolbox.org/c/otb-chains/s1-tiling/11

.. |License| image:: https://img.shields.io/pypi/l/s1tiling.svg
   :target: https://pypi.org/project/s1tiling/

.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/s1tiling.svg
   :target: https://pypi.org/project/s1tiling/

On demand Ortho-rectification of Sentinel-1 data on Sentinel-2 grid.

.. toctree::
   :maxdepth: 3
   :caption: User Guide:

   intro
   install
   use
   dataflow
   files
   CNES
   FAQ
   release_notes

.. toctree::
   :maxdepth: 3
   :caption: Developer Documentation:

   contribute
   developers
   how-to-developers
   testing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
